#!/bin/bash
#
# We only need the header files, but we have to build the binary 
# to get the headers.  This means we can use the native compiler.

# buildCstxsd.sh <product_directory> <gcc482> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e15|e14|e10> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}
sourcetar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=cstxsd
origpkgver=v4_0_0
pkgver=${origpkgver}g
ssibuildshims_version=v1_03_02

get_this_dir

get_ssibuildshims

source define_basics NO_TYPE

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${basequal}
    exit 0
fi

OS2=`echo ${OS} | cut -f1 -d"-"`

echo "building ${package} for ${OS2}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${basequal}

export CSTXSD_J=`${SSIBUILDSHIMS_DIR}/bin/ncores`
if [[ ${OS2} == "d15" ]]
then
  ${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${basequal}:build
  setup -B ${package} ${pkgver} -q +${basequal}:+build -z ${fakedb}:${product_dir}:${PRODUCTS} || \
            ssi_die "ERROR: fake setup failed"
  set -x
  # weird problem only on El Capitan
  cd ${CSTXSD_FQ_DIR}
  tar xf ${CSTXSD_DIR}/tar/xsd-4.0.0+dep.tar.bz2
  cd ${CSTXSD_FQ_DIR}/xsd-4.0.0+dep
  make install_prefix="${CSTXSD_FQ_DIR}" \
       CXXFLAGS="-std=c++11 -O3 -gdwarf-2 -I${XERCESCROOT}/include" \
       CPPFLAGS="-I${XERCESCROOT}/include" \
       LDFLAGS="-L${XERCESCROOT}/lib" \
       .LIBPATTERNS=lib%.a \
       LIBS="-lpthread -lcurl  -framework CoreServices -framework CoreFoundation" \
       ${CSTXSD_J:+-j ${CSTXSD_J}} install \
       || ssi_die "make install failed"
  make clean || ssi_die "make clean failed"
  set +x
else
 ups build cstxsd ${pkgver} -q ${basequal} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: Unable to build cstxsd"
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${basequal} || ssi_die "ERROR: declare failed"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${basequal}  -z ${product_dir}:${PRODUCTS}
echo "${package} is installed at ${CSTXSD_FQ_DIR}"
echo ""

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${basequal}
fi

exit 0
